/*
 * This Java source file was generated by the Gradle 'init' task.
 */
package lightcontainer;

import lightcontainer.domains.server.MulticastServerListener;
import lightcontainer.domains.server.UnicastServerListener;
import lightcontainer.interfaces.ProtocolRepository;
import lightcontainer.protocol.rules.reader.*;
import lightcontainer.protocol.rules.writer.*;
import lightcontainer.repository.ClientHandlerRepository;
import lightcontainer.repository.FileFrontEnd;
import lightcontainer.repository.ProtocolRepositoryImpl;
import lightcontainer.repository.StoreProcessorRepository;

import java.io.File;

public class App {
    // Constant config server
    // -- Unicast client port
    private static final int UNICAST_PORT = 8000;
    // -- Multicast listener ip, port
    private static final String MULTICAST_IP = "226.66.66.1";
    private static final int MULTICAST_PORT = 15502;


    /*
    private static Thread t1 = null;

    public static void main(String[] args) throws InterruptedException {
        t1 = new Thread(new Runnable() {
            @Override
            public void run() {
                int i = 0;
                while (true) {
                    System.out.println("HEY " + i++);

                    try {
                        synchronized (t1) {
                            System.out.println("SUSPEND");
                            t1.wait();
                        }
                    } catch (InterruptedException e) {}
                }
            }
        });
        t1.start();
        System.out.println("START");
        Thread.sleep(1000);
        synchronized (t1) {
            t1.notify();
        }
    }
    */

    public static void main(String[] args) throws InterruptedException {
        setupVM();

        // Create all repository
        ClientHandlerRepository clientRep = new ClientHandlerRepository();
        StoreProcessorRepository storeRep = new StoreProcessorRepository();
        ProtocolRepository protocolRep = new ProtocolRepositoryImpl();
        protocolRep.addReader(new HelloRule());
        protocolRep.addReader(new SigninRule(protocolRep));
        protocolRep.addReader(new FilelistRule(protocolRep));
        protocolRep.addReader(new SavefileRule(protocolRep));
        protocolRep.addReader(new SendOkRule(protocolRep));

        protocolRep.addWriter(new SignOkRule());
        protocolRep.addWriter(new SignErrorRule());
        protocolRep.addWriter(new SignoutRule());
        protocolRep.addWriter(new FilesRule());
        protocolRep.addWriter(new SaveFileOkRule());
        protocolRep.addWriter(new SaveFileErrorRule());
        protocolRep.addWriter(new SendfileRule());

        FileFrontEnd ffe = new FileFrontEnd(clientRep, storeRep, protocolRep);
        new UnicastServerListener(ffe, clientRep, protocolRep, UNICAST_PORT);
        new MulticastServerListener(ffe, storeRep, protocolRep, MULTICAST_IP, MULTICAST_PORT);

        // close repo et client et server.

        // Thread.sleep(60000);

        // clientRep.close();
        // storeRep.close();
    }

    private static void setupVM() {
        System.setProperty("javax.net.ssl.keyStore","../ffe.labo.swilabus.com.p12");
        System.setProperty("javax.net.ssl.keyStorePassword","labo2022");
        System.setProperty("https.protocols","TLSv1.3");
    }

}
