package lightcontainer.protocol.rules.reader;

import lightcontainer.domains.client.Context;
import lightcontainer.interfaces.ProtocolRepository;
import lightcontainer.protocol.ProtocolReader;
import lightcontainer.protocol.rules.writer.SaveFileErrorRule;
import lightcontainer.protocol.rules.writer.SignErrorRule;
import lightcontainer.protocol.rules.writer.SignOkRule;

import java.io.InputStream;

public class SigninRule extends ProtocolReader {
    // Constants
    private static final String PATTERN = "^(SIGNIN) ([A-Za-z0-9]{5,20}) ([^ !]{5,50})\r\n$";

    private static final String NAME = "SIGNIN";

    private static final int LOGIN = 0;  // Index du domain dans le tableau de données
    private static final int PASSWORD = 1;  // Index du port dans le tableau de données

    private ProtocolRepository protocolRep;

    // Constructor
    public SigninRule(ProtocolRepository protocolRep) {
        super(NAME, PATTERN);
        this.protocolRep = protocolRep;
    }

    public class Result extends ProtocolResult {
        // Variables
        private final String login;
        private final String password;

        // Result constructor
        public Result(String login, String password) {
            this.login = login;
            this.password = password;
        }

        public String getLogin() {
            return login;
        }

        public String getPassword() {
            return password;
        }

        public boolean checkCredentials() {
            return getLogin().equals("aaaaa") && getPassword().equals("aaaaa");
        }
    }

    @Override
    protected SigninRule.Result onExecuted(Context context, String... data) {
        SigninRule.Result result = new SigninRule.Result(data[LOGIN], data[PASSWORD]);

        // TODO : Création d'une règle d'écriture SIGN_OK et SIGN_ERROR proprement
        if (result.checkCredentials()) {
            result.setResultCommand(this.protocolRep.executeWriter(SignOkRule.NAME), ResultCmdReceiver.CLIENT);
        } else {
            result.setResultCommand(this.protocolRep.executeWriter(SignErrorRule.NAME), ResultCmdReceiver.CLIENT);
        }
        return result;
    }

    @Override
    protected ProtocolReader.ProtocolResult onError() {
        ProtocolReader.ProtocolResult result = new ProtocolReader.ProtocolResult();

        result.setResultCommand(protocolRep.executeWriter(SignErrorRule.NAME), ResultCmdReceiver.CLIENT);
        return result;
    }
}
