package lightcontainer.storage;

import org.junit.jupiter.api.Test;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import static org.junit.jupiter.api.Assertions.*;


public class JsonAdapterTests {

    @Test
    public void convertAppDataToJson() {
        //GIVEN an AppData instance and a Json Adapter
        AppData appData = AppData.getInstance();
        AppConfig appConfig = AppConfig.getInstance();
        appConfig.setUnicastPort(32000);
        appConfig.setMulticastIp("224.25.0.1");
        appConfig.setMulticastPort(15502);
        appConfig.setNetworkInterface("My network interface");
        appConfig.setTls(false);
        Map<String, File> files = new HashMap<>();
        Set<String> storage = new HashSet<>();
        storage.add("StorBackEnd1");
        File file1 = new File("File1", 15, "8d8d8d8d", storage);
        files.put(file1.getName(), file1);
        User user1 = new User("User1", "Password", "djdjjdj", files);
        appData.setAppConfig(appConfig);
        //appData.addUser(user1);
        JsonAdapter jsonAdapter = new JsonAdapter(appData);
        //WHEN the adapter converts AppData to Json
        String jsonAppData = jsonAdapter.toString();
        //THEN
        assertTrue(jsonAppData.contains("32000"));
        assertTrue(jsonAppData.contains("224.25.0.1"));
        assertTrue(jsonAppData.contains("15502"));
        assertTrue(jsonAppData.contains("My network interface"));
        assertTrue(jsonAppData.contains("false"));
        assertTrue(jsonAppData.contains("User1"));
        assertTrue(jsonAppData.contains("Password"));
        assertTrue(jsonAppData.contains("djdjjdj"));
        assertTrue(jsonAppData.contains("File1"));
        assertTrue(jsonAppData.contains("15"));
        assertTrue(jsonAppData.contains("8d8d8d8d"));
        assertTrue(jsonAppData.contains("StorBackEnd1"));
    }

    @Test
    public void convertJsonToAppData() {
        //GIVEN a Json string
        String json = "{\"unicast_port\":32000,\"multicast_ip\":\"224.25.0.1\",\"multicast_port\":15502,\"network_interface\":\"My network interface\",\"tls\":false,\"users\":[{\"name\":\"User1\",\"password\":\"Password\",\"aes_key\":\"djdjjdj\",\"files\":[{\"name\":\"File1\",\"size\":15,\"iv\":\"8d8d8d8d\",\"storage\":[\"StorBackEnd1\"]}]}]}";
        //WHEN the adapter converts Json to Appdata
        JsonAdapter jsonAdapter = new JsonAdapter(null);
        AppData appData = jsonAdapter.fromString(json);
        //THEN
        assertNotNull(appData.getAppConfig());
        assertEquals("My network interface", appData.getAppConfig().getNetworkInterface());
        assertEquals(32000, appData.getAppConfig().getUnicastPort());
        assertEquals("224.25.0.1", appData.getAppConfig().getMulticastIp());
        assertEquals(15502, appData.getAppConfig().getMulticastPort());
        assertFalse(appData.getAppConfig().isTls());
    }
}
