package lightcontainer.storage;

import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.InvalidPathException;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import static org.junit.jupiter.api.Assertions.*;


public class RepositoryTests {

    @AfterEach
    public void destroyTestFile() {
        try {
            Files.deleteIfExists(Paths.get("src", "test", "resources", "test.json").toAbsolutePath());
        } catch (IOException e) {
            System.out.println("Error while destroying file");
        }
    }

    @Test
    public void save() {
        //GIVEN an AppData instance and a Json Adapter
        AppData appData = AppData.getInstance();
        AppConfig appConfig = AppConfig.getInstance();
        appConfig.setUnicastPort(32000);
        appConfig.setMulticastIp("224.25.0.1");
        appConfig.setMulticastPort(15502);
        appConfig.setNetworkInterface("My network interface");
        appConfig.setTls(false);
        Map<String, File> files = new HashMap<>();
        Set<String> storage = new HashSet<>();
        storage.add("StorBackEnd1");
        File file1 = new File("File1", 15, "8d8d8d8d", storage);
        files.put(file1.getName(), file1);
        User user1 = new User("User1", "Password", "djdjjdj", files);
        appData.setAppConfig(appConfig);
        //appData.addUser(user1);
        JsonAdapter jsonAdapter = new JsonAdapter(appData);
        //WHEN Repository calls save method
        String filePath = "src/test/resources/test.json";
        Repository.save(filePath, jsonAdapter);
        //THEN
        assertTrue(Files.exists(Paths.get("src/test/resources/test.json").toAbsolutePath()));
    }

    @Test
    public void load() {
        //GIVEN a test json file loadTest.json
        JsonAdapter jsonAdapter = new JsonAdapter(null);
        //WHEN repository calls load method
        AppData appData = Repository.load("src/test/resources/loadTest.json", jsonAdapter);
        //THEN
        assertNotNull(appData.getAppConfig());
        assertEquals("My network interface", appData.getAppConfig().getNetworkInterface());
        assertEquals(32000, appData.getAppConfig().getUnicastPort());
        assertEquals("224.25.0.1", appData.getAppConfig().getMulticastIp());
        assertEquals(15502, appData.getAppConfig().getMulticastPort());
        assertFalse(appData.getAppConfig().isTls());
    }
}
